@@ -1,9 +1,6 @@
 
-#undef PRODUCT_NAME
-#define PRODUCT_NAME "IPFire Boot Server (boot.ipfire.org)"
-
 // Enable support for syslinux's com32 images.
-#define IMAGE_COMBOOT
+//#define IMAGE_COMBOOT
 
 // Enable support for FTP and HTTPS downloads.
 #define DOWNLOAD_PROTO_FTP
